# Ansible Navigator Documentation

`ansible-navigator` is a command-line tool and a text-based user interface (TUI)
for creating, reviewing, running and troubleshooting Ansible content, including
inventories, playbooks, collections, documentation and container images
(execution environments).

A demo of the interface can be found [on YouTube][yt demo].

[yt demo]: https://www.youtube.com/watch?v=J9PBKi8ydi4

To learn how to easily start leveraging the container technology with
`ansible-navigator`, see the
[Getting started with Execution Environments guide](https://docs.ansible.com/ansible/devel/getting_started_ee/index.html).

- [Installation](installation.md)
- [Settings](settings.md)
- [Subcommands](subcommands.md)
- [FAQ](faq.md)

Contributions

- [Code Of Conduct](contributing/code-of-conduct)
- [Security](contributing/security)
- [Guidelines](contributing/guidelines)
